var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
import { ICommitmentWrapperType, IMembershipWrapperType, MembershipWrapper, } from "@snickerdoodlelabs/circuits-sdk";
import { IAxiosAjaxUtilsType, ObjectUtils, } from "@snickerdoodlelabs/common-utils";
import { inject, injectable } from "inversify";
import { urlJoin } from "url-join-ts";
let InsightPlatformRepository = class InsightPlatformRepository {
    constructor(ajaxUtils, membershipWrapper, commitmentWrapper) {
        this.ajaxUtils = ajaxUtils;
        this.membershipWrapper = membershipWrapper;
        this.commitmentWrapper = commitmentWrapper;
    }
    deliverInsights(consentContractAddress, trapdoor, nullifier, queryCID, insights, rewardParameters, anonymitySet, anonymitySetStart, insightPlatformBaseUrl) {
        // Calculate the values we need to include in the signal
        const identity = MembershipWrapper.getIdentity(trapdoor, nullifier);
        const signalNullifier = MembershipWrapper.getSignalNullifier(identity, queryCID);
        // Check if the passed-in anonymity set includes the identity's commitment
        let anonymitySetSize = anonymitySet.length;
        const identityCommitment = MembershipWrapper.getIdentityCommitment(identity);
        if (anonymitySet.indexOf(identityCommitment) === -1) {
            anonymitySetSize += 1;
        }
        const serializedInsights = ObjectUtils.serialize(insights);
        const serializedRewardParameters = ObjectUtils.serialize(rewardParameters);
        // Create the provable data
        const signal = {
            consentContractId: consentContractAddress,
            queryCID: queryCID,
            insights: serializedInsights,
            rewardParameters: serializedRewardParameters,
            signalNullifier: signalNullifier,
            anonymitySetStart: anonymitySetStart,
            anonymitySetSize: anonymitySetSize,
        };
        return this.membershipWrapper
            .prove(ObjectUtils.serialize(signal), trapdoor, nullifier, anonymitySet, queryCID)
            .andThen((proof) => {
            const url = new URL(urlJoin(insightPlatformBaseUrl, "insights/responses"));
            return this.ajaxUtils.post(url, {
                consentContractId: consentContractAddress,
                queryCID: queryCID,
                insights: serializedInsights,
                rewardParameters: serializedRewardParameters,
                signalNullifier: signalNullifier,
                anonymitySetStart: anonymitySetStart,
                anonymitySetSize: anonymitySetSize,
                proof: proof,
            });
        });
    }
    optin(consentContractAddress, trapdoor, nullifier, insightPlatformBaseUrl) {
        // Calculate the values we need to include in the signal
        const identity = MembershipWrapper.getIdentity(trapdoor, nullifier);
        const identityCommitment = MembershipWrapper.getIdentityCommitment(identity);
        // Create the provable data
        const signal = {
            consentContractId: consentContractAddress,
            commitment: identityCommitment,
        };
        return this.commitmentWrapper
            .prove(ObjectUtils.serialize(signal), trapdoor, nullifier)
            .andThen((proof) => {
            const url = new URL(urlJoin(insightPlatformBaseUrl, "optin"));
            return this.ajaxUtils.post(url, {
                consentContractId: consentContractAddress,
                commitment: identityCommitment.toString(),
                proof: proof,
            });
        })
            .map(() => { });
    }
    privateOptin(consentContractAddress, trapdoor, nullifier, nonce, signature, insightPlatformBaseUrl) {
        // Calculate the values we need to include in the signal
        const identity = MembershipWrapper.getIdentity(trapdoor, nullifier);
        const identityCommitment = MembershipWrapper.getIdentityCommitment(identity);
        // Create the provable data
        const signal = {
            consentContractId: consentContractAddress,
            commitment: identityCommitment,
            nonce: nonce,
            signature: signature,
        };
        return this.commitmentWrapper
            .prove(ObjectUtils.serialize(signal), trapdoor, nullifier)
            .andThen((proof) => {
            const url = new URL(urlJoin(insightPlatformBaseUrl, "optin"));
            return this.ajaxUtils.post(url, {
                consentContractId: consentContractAddress,
                commitment: identityCommitment.toString(),
                proof: proof,
            });
        })
            .map(() => { });
    }
};
InsightPlatformRepository = __decorate([
    injectable(),
    __param(0, inject(IAxiosAjaxUtilsType)),
    __param(1, inject(IMembershipWrapperType)),
    __param(2, inject(ICommitmentWrapperType)),
    __metadata("design:paramtypes", [Object, Object, Object])
], InsightPlatformRepository);
export { InsightPlatformRepository };
//# sourceMappingURL=InsightPlatformRepository.js.map